==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/ThisWeekExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { OffsettableWeekExpressionDescriptionMetadata } from "./OffsettableWeekExpressionDescriptionMetadata";
import { ThisWeekExpressionDescription } from "./ThisWeekExpressionDescription";
/**
 * @hidden
 */
export let ThisWeekExpressionDescriptionMetadata = /*@__PURE__*/ (() => {
    class ThisWeekExpressionDescriptionMetadata extends Base {
        static b(a) {
            if (ThisWeekExpressionDescriptionMetadata.a == null) {
                ThisWeekExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ThisWeekExpressionDescriptionMetadata.c(ThisWeekExpressionDescriptionMetadata.a);
            }
            if (a.k(ThisWeekExpressionDescriptionMetadata.a)) {
                return;
            }
            a.ab(ThisWeekExpressionDescriptionMetadata.a);
        }
        static c(a) {
            OffsettableWeekExpressionDescriptionMetadata.c(a);
        }
        static d(a) {
            ThisWeekExpressionDescriptionMetadata.b(a);
            a.ad("ThisWeekExpression", () => new ThisWeekExpressionDescription());
            a.ac("ThisWeekExpression", ThisWeekExpressionDescriptionMetadata.a);
        }
    }
    ThisWeekExpressionDescriptionMetadata.$t = markType(ThisWeekExpressionDescriptionMetadata, 'ThisWeekExpressionDescriptionMetadata');
    ThisWeekExpressionDescriptionMetadata.a = null;
    return ThisWeekExpressionDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/ThisWeekExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { OffsettableWeekExpressionDescriptionMetadata } from "./OffsettableWeekExpressionDescriptionMetadata";
import { ThisWeekExpressionDescription } from "./ThisWeekExpressionDescription";
/**
 * @hidden
 */
export let ThisWeekExpressionDescriptionMetadata = /*@__PURE__*/ (() => {
    class ThisWeekExpressionDescriptionMetadata extends Base {
        static b(a) {
            if (ThisWeekExpressionDescriptionMetadata.a == null) {
                ThisWeekExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ThisWeekExpressionDescriptionMetadata.c(ThisWeekExpressionDescriptionMetadata.a);
            }
            if (a.k(ThisWeekExpressionDescriptionMetadata.a)) {
                return;
            }
            a.ac(ThisWeekExpressionDescriptionMetadata.a);
        }
        static c(a) {
            OffsettableWeekExpressionDescriptionMetadata.c(a);
        }
        static d(a) {
            ThisWeekExpressionDescriptionMetadata.b(a);
            a.ae("ThisWeekExpression", () => new ThisWeekExpressionDescription());
            a.ad("ThisWeekExpression", ThisWeekExpressionDescriptionMetadata.a);
        }
    }
    ThisWeekExpressionDescriptionMetadata.$t = markType(ThisWeekExpressionDescriptionMetadata, 'ThisWeekExpressionDescriptionMetadata');
    ThisWeekExpressionDescriptionMetadata.a = null;
    return ThisWeekExpressionDescriptionMetadata;
})();
